var VueTinyPagination = (function () {
  'use strict';

  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //
  //

  var script = {
    name: 'TinyPagination',
    props: {
      total: {
        type: Number,
        required: true,
      },
      page: {
        type: Number,
        default: 1,
      },
      lang: {
        type: String,
        default: 'en',
      },
      customClass: {
        type: String,
      },
      limits: {
        type: Array,
        default () {
          return [10, 15, 20, 50, 100];
        },
      },
      showLimit: {
        type: Boolean,
        default: true,
      }
    },
    data () {
      return {
        version: '0.3.0',
        currentPage: 1,
        currentLimit: 10,
        translations: {
          en: {
            prev: 'Previous',
            title: 'Page',
            next: 'Next',
          },
          es: {
            prev: 'Anterior',
            title: 'Página',
            next: 'Siguiente',
          }
        },
        availableLanguages: ['en', 'es'],
      };
    },
    created () {
      this.currentPage = this.page;
    },
    computed: {
      translation () {
        return (this.availableLanguages.includes(this.lang)) ?
          this.translations[this.lang]
        : this.translations['en']
      },
      totalPages () {
        return Math.ceil(this.total/this.currentLimit)
      },
      titlePage () {
        return `${this.translation.title} ${this.currentPage}`
      },
      classFirstPage () {
        return {
          disabled: (this.currentPage === 1),
          'c-not-allowed': true
        }
      },
      classLastPage () {
        return {
          disabled: (this.currentPage === this.totalPages),
          'c-not-allowed': true
        }
      }
    },
    methods: {
      nextPage () {
        if (this.currentPage !== this.totalPages) {
          this.currentPage += 1;
        }
      },
      lastPage () {
        if (this.currentPage > 1) {
          this.currentPage -= 1;
        }
      },
      onLimitChange () {
        this.currentPage = 1;
      }
    },
    watch: {
      currentPage (value) {
        this.$emit('tiny:change-page', {
          page: value
        });
      },
      currentLimit (value) {
        this.$emit('tiny:change-limit', {
          limit: value
        });
      }
    }
  };

  function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier
  /* server only */
  , shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
      createInjectorSSR = createInjector;
      createInjector = shadowMode;
      shadowMode = false;
    } // Vue.extend constructor export interop.


    var options = typeof script === 'function' ? script.options : script; // render functions

    if (template && template.render) {
      options.render = template.render;
      options.staticRenderFns = template.staticRenderFns;
      options._compiled = true; // functional template

      if (isFunctionalTemplate) {
        options.functional = true;
      }
    } // scopedId


    if (scopeId) {
      options._scopeId = scopeId;
    }

    var hook;

    if (moduleIdentifier) {
      // server build
      hook = function hook(context) {
        // 2.3 injection
        context = context || // cached call
        this.$vnode && this.$vnode.ssrContext || // stateful
        this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
        // 2.2 with runInNewContext: true

        if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
          context = __VUE_SSR_CONTEXT__;
        } // inject component styles


        if (style) {
          style.call(this, createInjectorSSR(context));
        } // register component module identifier for async chunk inference


        if (context && context._registeredComponents) {
          context._registeredComponents.add(moduleIdentifier);
        }
      }; // used by ssr in case component is cached and beforeCreate
      // never gets called


      options._ssrRegister = hook;
    } else if (style) {
      hook = shadowMode ? function () {
        style.call(this, createInjectorShadow(this.$root.$options.shadowRoot));
      } : function (context) {
        style.call(this, createInjector(context));
      };
    }

    if (hook) {
      if (options.functional) {
        // register for functional component in vue file
        var originalRender = options.render;

        options.render = function renderWithStyleInjection(h, context) {
          hook.call(context);
          return originalRender(h, context);
        };
      } else {
        // inject component registration as beforeCreate hook
        var existing = options.beforeCreate;
        options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
      }
    }

    return script;
  }

  var normalizeComponent_1 = normalizeComponent;

  var isOldIE = typeof navigator !== 'undefined' && /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());
  function createInjector(context) {
    return function (id, style) {
      return addStyle(id, style);
    };
  }
  var HEAD = document.head || document.getElementsByTagName('head')[0];
  var styles = {};

  function addStyle(id, css) {
    var group = isOldIE ? css.media || 'default' : id;
    var style = styles[group] || (styles[group] = {
      ids: new Set(),
      styles: []
    });

    if (!style.ids.has(id)) {
      style.ids.add(id);
      var code = css.source;

      if (css.map) {
        // https://developer.chrome.com/devtools/docs/javascript-debugging
        // this makes source maps inside style tags work properly in Chrome
        code += '\n/*# sourceURL=' + css.map.sources[0] + ' */'; // http://stackoverflow.com/a/26603875

        code += '\n/*# sourceMappingURL=data:application/json;base64,' + btoa(unescape(encodeURIComponent(JSON.stringify(css.map)))) + ' */';
      }

      if (!style.element) {
        style.element = document.createElement('style');
        style.element.type = 'text/css';
        if (css.media) style.element.setAttribute('media', css.media);
        HEAD.appendChild(style.element);
      }

      if ('styleSheet' in style.element) {
        style.styles.push(code);
        style.element.styleSheet.cssText = style.styles.filter(Boolean).join('\n');
      } else {
        var index = style.ids.size - 1;
        var textNode = document.createTextNode(code);
        var nodes = style.element.childNodes;
        if (nodes[index]) style.element.removeChild(nodes[index]);
        if (nodes.length) style.element.insertBefore(textNode, nodes[index]);else style.element.appendChild(textNode);
      }
    }
  }

  var browser = createInjector;

  /* script */
  const __vue_script__ = script;

  /* template */
  var __vue_render__ = function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c("div", { staticClass: "vue-tiny-pagination" }, [
      _c("ul", { staticClass: "tiny-pagination", class: _vm.customClass }, [
        _c("li", { staticClass: "page-item", class: _vm.classFirstPage }, [
          _c(
            "a",
            {
              staticClass: "btn-prev-page",
              attrs: { href: "#" },
              on: {
                click: function($event) {
                  $event.preventDefault();
                  return _vm.lastPage($event)
                }
              }
            },
            [_vm._v(_vm._s(_vm.translation.prev))]
          )
        ]),
        _vm._v(" "),
        _c("li", { staticClass: "page-item" }, [
          _c("span", [_vm._v(_vm._s(_vm.titlePage))])
        ]),
        _vm._v(" "),
        _c("li", { staticClass: "page-item", class: _vm.classLastPage }, [
          _c(
            "a",
            {
              staticClass: "btn-next-page",
              attrs: { href: "#" },
              on: {
                click: function($event) {
                  $event.preventDefault();
                  return _vm.nextPage($event)
                }
              }
            },
            [_vm._v(_vm._s(_vm.translation.next))]
          )
        ]),
        _vm._v(" "),
        _vm.showLimit
          ? _c("li", { staticClass: "page-item" }, [
              _c(
                "select",
                {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.currentLimit,
                      expression: "currentLimit"
                    }
                  ],
                  staticClass: "tiny-form-select",
                  on: {
                    change: [
                      function($event) {
                        var $$selectedVal = Array.prototype.filter
                          .call($event.target.options, function(o) {
                            return o.selected
                          })
                          .map(function(o) {
                            var val = "_value" in o ? o._value : o.value;
                            return val
                          });
                        _vm.currentLimit = $event.target.multiple
                          ? $$selectedVal
                          : $$selectedVal[0];
                      },
                      _vm.onLimitChange
                    ]
                  }
                },
                _vm._l(_vm.limits, function(limit, index) {
                  return _c(
                    "option",
                    { key: index, domProps: { value: limit } },
                    [_vm._v(_vm._s(limit) + "/" + _vm._s(_vm.translation.title))]
                  )
                })
              )
            ])
          : _vm._e()
      ])
    ])
  };
  var __vue_staticRenderFns__ = [];
  __vue_render__._withStripped = true;

    /* style */
    const __vue_inject_styles__ = function (inject) {
      if (!inject) return
      inject("data-v-79c9d99f_0", { source: "@charset \"UTF-8\";\n.tiny-pagination {\n  font-family: -apple-system, system-ui, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", sans-serif;\n  display: flex;\n  list-style: none;\n  margin: .2rem 0;\n  padding: .2rem 0;\n}\n.tiny-pagination .page-item {\n    margin: .2rem .05rem;\n}\n.tiny-pagination .page-item span {\n      display: inline-block;\n      padding: .2rem .2rem;\n}\n.tiny-pagination .page-item a {\n      border-radius: .1rem;\n      color: #667189;\n      display: inline-block;\n      padding: .2rem .4rem;\n      text-decoration: none;\n}\n.tiny-pagination .page-item a:focus, .tiny-pagination .page-item a:hover {\n        color: #5755d9;\n}\n.tiny-pagination .page-item.disabled a {\n      cursor: default;\n      opacity: .5;\n      pointer-events: none;\n}\n.tiny-pagination .page-item.active a {\n      background: #5755d9;\n      color: #fff;\n}\n.tiny-pagination .page-item.page-prev, .tiny-pagination .page-item.page-next {\n      flex: 1 0 50%;\n}\n.tiny-pagination .page-item.page-next {\n      text-align: right;\n}\n.tiny-pagination .page-item .page-item-title {\n      margin: 0;\n}\n.tiny-pagination .page-item .page-item-subtitle {\n      margin: 0;\n      opacity: .5;\n}\n.tiny-pagination .tiny-form-select {\n    -webkit-appearance: none;\n    -moz-appearance: none;\n    appearance: none;\n    text-transform: lowercase;\n    border: .05rem solid #caced7;\n    border-radius: .1rem;\n    font-size: .8rem;\n    height: 1.8rem;\n    line-height: 1rem;\n    outline: none;\n    padding: .35rem .4rem;\n    vertical-align: middle;\n    width: 100%;\n}\n.tiny-pagination .tiny-form-select:focus {\n      border-color: #5755d9;\n      box-shadow: 0 0 0 0.1rem rgba(87, 85, 217, 0.2);\n}\n.tiny-pagination .tiny-form-select:not([multiple]):not([size]) {\n    background: #fff url('data:image/svg+xml;charset=utf8,%3Csvg%20xmlns=\"http://www.w3.org/2000/svg\"…path%20fill=\"%23667189\"%20d=\"M2%200L0%202h4zm0%205L0%203h4z\"/%3E%3C/svg%3E') no-repeat right 0.35rem center/0.4rem 0.5rem;\n    padding-right: 1.2rem;\n}\n\n/*# sourceMappingURL=main.vue.map */", map: {"version":3,"sources":["main.vue","/Users/coderdiaz/github.com/coderdiaz/vue-tiny-pagination/packages/TinyPagination/src/main.vue"],"names":[],"mappings":"AAAA,gBAAgB;ACsIhB;EACA,2GAAA;EACA,aAAA;EACA,gBAAA;EACA,eAAA;EACA,gBAAA;AAAA;AALA;IAQA,oBAAA;AAAA;AARA;MAWA,qBAAA;MACA,oBAAA;AAAA;AAZA;MAgBA,oBAAA;MACA,cAAA;MACA,qBAAA;MACA,oBAAA;MACA,qBAAA;AAAA;AApBA;QAuBA,cAAA;AAAA;AAvBA;MA6BA,eAAA;MACA,WAAA;MACA,oBAAA;AAAA;AA/BA;MAqCA,mBAAA;MACA,WAAA;AAAA;AAtCA;MA4CA,aAAA;AAAA;AA5CA;MAgDA,iBAAA;AAAA;AAhDA;MAoDA,SAAA;AAAA;AApDA;MAwDA,SAAA;MACA,WAAA;AAAA;AAzDA;IA8DA,wBAAA;IACA,qBAAA;IACA,gBAAA;IACA,yBAAA;IACA,4BAAA;IACA,oBAAA;IACA,gBAAA;IACA,cAAA;IACA,iBAAA;IACA,aAAA;IACA,qBAAA;IACA,sBAAA;IACA,WAAA;AAAA;AA1EA;MA4EA,qBAAA;MACA,+CAAA;AAAA;AA7EA;IAkFA,2NAAA;IACA,qBAAA;AAAA;;ADhKA,mCAAmC","file":"main.vue","sourcesContent":["@charset \"UTF-8\";\n.tiny-pagination {\n  font-family: -apple-system, system-ui, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", sans-serif;\n  display: flex;\n  list-style: none;\n  margin: .2rem 0;\n  padding: .2rem 0; }\n  .tiny-pagination .page-item {\n    margin: .2rem .05rem; }\n    .tiny-pagination .page-item span {\n      display: inline-block;\n      padding: .2rem .2rem; }\n    .tiny-pagination .page-item a {\n      border-radius: .1rem;\n      color: #667189;\n      display: inline-block;\n      padding: .2rem .4rem;\n      text-decoration: none; }\n      .tiny-pagination .page-item a:focus, .tiny-pagination .page-item a:hover {\n        color: #5755d9; }\n    .tiny-pagination .page-item.disabled a {\n      cursor: default;\n      opacity: .5;\n      pointer-events: none; }\n    .tiny-pagination .page-item.active a {\n      background: #5755d9;\n      color: #fff; }\n    .tiny-pagination .page-item.page-prev, .tiny-pagination .page-item.page-next {\n      flex: 1 0 50%; }\n    .tiny-pagination .page-item.page-next {\n      text-align: right; }\n    .tiny-pagination .page-item .page-item-title {\n      margin: 0; }\n    .tiny-pagination .page-item .page-item-subtitle {\n      margin: 0;\n      opacity: .5; }\n  .tiny-pagination .tiny-form-select {\n    -webkit-appearance: none;\n    -moz-appearance: none;\n    appearance: none;\n    text-transform: lowercase;\n    border: .05rem solid #caced7;\n    border-radius: .1rem;\n    font-size: .8rem;\n    height: 1.8rem;\n    line-height: 1rem;\n    outline: none;\n    padding: .35rem .4rem;\n    vertical-align: middle;\n    width: 100%; }\n    .tiny-pagination .tiny-form-select:focus {\n      border-color: #5755d9;\n      box-shadow: 0 0 0 0.1rem rgba(87, 85, 217, 0.2); }\n  .tiny-pagination .tiny-form-select:not([multiple]):not([size]) {\n    background: #fff url('data:image/svg+xml;charset=utf8,%3Csvg%20xmlns=\"http://www.w3.org/2000/svg\"…path%20fill=\"%23667189\"%20d=\"M2%200L0%202h4zm0%205L0%203h4z\"/%3E%3C/svg%3E') no-repeat right 0.35rem center/0.4rem 0.5rem;\n    padding-right: 1.2rem; }\n\n/*# sourceMappingURL=main.vue.map */","<template>\n  <div class=\"vue-tiny-pagination\">\n    <ul class=\"tiny-pagination\" :class=\"customClass\">\n      <li class=\"page-item\" :class=\"classFirstPage\">\n        <a class=\"btn-prev-page\" href=\"#\" @click.prevent=\"lastPage\">{{translation.prev}}</a>\n      </li>\n      <li class=\"page-item\">\n        <span>{{titlePage}}</span>\n      </li>\n      <li class=\"page-item\" :class=\"classLastPage\">\n        <a class=\"btn-next-page\" href=\"#\" @click.prevent=\"nextPage\">{{translation.next}}</a>\n      </li>\n      <li v-if=\"showLimit\" class=\"page-item\">\n        <select class=\"tiny-form-select\" v-model=\"currentLimit\" @change=\"onLimitChange\">\n          <option\n            v-for=\"(limit, index) in limits\"\n            :value=\"limit\"\n            :key=\"index\">{{limit}}/{{translation.title}}</option>\n        </select>\n      </li>\n    </ul>\n  </div>\n</template>\n\n<script>\nexport default {\n  name: 'TinyPagination',\n  props: {\n    total: {\n      type: Number,\n      required: true,\n    },\n    page: {\n      type: Number,\n      default: 1,\n    },\n    lang: {\n      type: String,\n      default: 'en',\n    },\n    customClass: {\n      type: String,\n    },\n    limits: {\n      type: Array,\n      default () {\n        return [10, 15, 20, 50, 100];\n      },\n    },\n    showLimit: {\n      type: Boolean,\n      default: true,\n    }\n  },\n  data () {\n    return {\n      version: '0.3.0',\n      currentPage: 1,\n      currentLimit: 10,\n      translations: {\n        en: {\n          prev: 'Previous',\n          title: 'Page',\n          next: 'Next',\n        },\n        es: {\n          prev: 'Anterior',\n          title: 'Página',\n          next: 'Siguiente',\n        }\n      },\n      availableLanguages: ['en', 'es'],\n    };\n  },\n  created () {\n    this.currentPage = this.page\n  },\n  computed: {\n    translation () {\n      return (this.availableLanguages.includes(this.lang)) ?\n        this.translations[this.lang]\n      : this.translations['en']\n    },\n    totalPages () {\n      return Math.ceil(this.total/this.currentLimit)\n    },\n    titlePage () {\n      return `${this.translation.title} ${this.currentPage}`\n    },\n    classFirstPage () {\n      return {\n        disabled: (this.currentPage === 1),\n        'c-not-allowed': true\n      }\n    },\n    classLastPage () {\n      return {\n        disabled: (this.currentPage === this.totalPages),\n        'c-not-allowed': true\n      }\n    }\n  },\n  methods: {\n    nextPage () {\n      if (this.currentPage !== this.totalPages) {\n        this.currentPage += 1\n      }\n    },\n    lastPage () {\n      if (this.currentPage > 1) {\n        this.currentPage -= 1\n      }\n    },\n    onLimitChange () {\n      this.currentPage = 1\n    }\n  },\n  watch: {\n    currentPage (value) {\n      this.$emit('tiny:change-page', {\n        page: value\n      })\n    },\n    currentLimit (value) {\n      this.$emit('tiny:change-limit', {\n        limit: value\n      })\n    }\n  }\n}\n</script>\n\n<style lang=\"scss\">\n// Pagination\n.tiny-pagination {\n  font-family: -apple-system, system-ui, BlinkMacSystemFont, \"Segoe UI\", Roboto, \"Helvetica Neue\", sans-serif;\n  display: flex;\n  list-style: none;\n  margin: .2rem 0;\n  padding: .2rem 0;\n\n  .page-item {\n    margin: .2rem .05rem;\n\n    span {\n      display: inline-block;\n      padding: .2rem .2rem;\n    }\n\n    a {\n      border-radius: .1rem;\n      color: #667189;\n      display: inline-block;\n      padding: .2rem .4rem;\n      text-decoration: none;\n      &:focus,\n      &:hover {\n        color: #5755d9;\n      }\n    }\n\n    &.disabled {\n      a {\n        cursor: default;\n        opacity: .5;\n        pointer-events: none;\n      }\n    }\n\n    &.active {\n      a {\n        background: #5755d9;\n        color: #fff;\n      }\n    }\n\n    &.page-prev,\n    &.page-next {\n      flex: 1 0 50%;\n    }\n\n    &.page-next {\n      text-align: right;\n    }\n\n    .page-item-title {\n      margin: 0;\n    }\n\n    .page-item-subtitle {\n      margin: 0;\n      opacity: .5;\n    }\n  }\n\n  .tiny-form-select {\n    -webkit-appearance: none;\n    -moz-appearance: none;\n    appearance: none;\n    text-transform: lowercase;\n    border: .05rem solid #caced7;\n    border-radius: .1rem;\n    font-size: .8rem;\n    height: 1.8rem;\n    line-height: 1rem;\n    outline: none;\n    padding: .35rem .4rem;\n    vertical-align: middle;\n    width: 100%;\n    &:focus {\n      border-color: #5755d9;\n      box-shadow: 0 0 0 0.1rem rgba(87, 85, 217, .2)\n    }\n  }\n\n  .tiny-form-select:not([multiple]):not([size]) {\n    background: #fff url('data:image/svg+xml;charset=utf8,%3Csvg%20xmlns=\"http://www.w3.org/2000/svg\"…path%20fill=\"%23667189\"%20d=\"M2%200L0%202h4zm0%205L0%203h4z\"/%3E%3C/svg%3E') no-repeat right .35rem center/.4rem .5rem;\n    padding-right: 1.2rem;\n  }\n}\n</style>"]}, media: undefined });

    };
    /* scoped */
    const __vue_scope_id__ = undefined;
    /* module identifier */
    const __vue_module_identifier__ = undefined;
    /* functional template */
    const __vue_is_functional_template__ = false;
    /* style inject SSR */
    

    
    var TinyPagination = normalizeComponent_1(
      { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
      __vue_inject_styles__,
      __vue_script__,
      __vue_scope_id__,
      __vue_is_functional_template__,
      __vue_module_identifier__,
      browser,
      undefined
    );

  TinyPagination.install = (Vue) => {
    Vue.component(TinyPagination.name, TinyPagination);
  };

  const install = (Vue) => {
    Vue.component(TinyPagination.name, TinyPagination);
  };

  if (typeof window !== 'undefined' && window.Vue) {
    install(window.Vue);
  }

  var index = {
    version: '0.3.0',
    install,
    TinyPagination,
  };

  return index;

}());
